@@ -1,5 +1,5 @@
 .onAttach <- function(libname, pkgname) {
-   packageStartupMessage(paste0(c("\n****\nWelcome to rNOMADS 2.5.1 \"Warp-field Stabilized\"!\n",
+   packageStartupMessage(paste0(c("\n****\nWelcome to rNOMADS 2.5.2 \"Indiscriminate Justice\"!\n",
    "Questions? Follow @dannycbowman on Twitter or send a message to rnomads-user@lists.r-forge.r-project.org\n",
    "Using rNOMADS as a data source for a publication?  Please cite it!\n****\n")))  
 }
